@@ -32,10 +32,7 @@ class NodeNetworkState(Resource):
             delete_timeout=delete_timeout,
         )
         status = self.instance.to_dict()["status"]
-        if "desiredState" in status:
-            self.desired_state = status["desiredState"]
-        else:
-            self.desired_state = {"interfaces": []}
+        self.desired_state = status.get("desiredState", {"interfaces": []})
 
     def set_interface(self, interface):
 
